@@ -1,6 +1,6 @@
 package App::JobLog::Log::Format;
 BEGIN {
-  $App::JobLog::Log::Format::VERSION = '1.007';
+  $App::JobLog::Log::Format::VERSION = '1.008';
 }
 
 # ABSTRACT: pretty printer for log
@@ -40,6 +40,7 @@ sub summary {
     my $skip_flex = $test || 0;
     $test //= sub { $_[0] };
     my ( $start, $end ) = parse $phrase;
+    my $show_year = $start->year < $end->year;
     unless ($skip_flex) {
 
      # if we are chopping off any of the first and last days we ignore flex time
@@ -66,11 +67,12 @@ sub summary {
     }
 
     # collect events into days
+    my @gathered;
     for my $big_e (@$events) {
         for my $e ( $big_e->split_days ) {
             if ( $e = $test->($e) ) {
+                push @gathered, shift @days while $days[0]->end < $e->start;
                 for my $d (@days) {
-                    next if $e->start > $d->end;
                     if ( $e->intersects( $d->pseudo_event ) ) {
                         push @{ $d->events }, $e;
                         last;
@@ -80,6 +82,7 @@ sub summary {
             }
         }
     }
+    unshift @days, @gathered;
 
     # add in vacation times
     for my $p (@periods) {
@@ -129,7 +132,7 @@ sub summary {
         $d->{events} = [ sort { $a->cmp($b) } @events ] if @events > 1;
     }
 
-    return \@days;
+    return \@days, $show_year;
 }
 
 # whether the date is the first moment in its day
@@ -171,14 +174,12 @@ sub _days {
 
 
 sub display {
-    my ( $days, $merge_level, $hidden, $screen_width ) = @_;
+    my ( $days, $merge_level, $hidden, $screen_width, $show_year ) = @_;
 
-    # TODO augment events with vacation and holidays
     if (@$days) {
         collect $_, $merge_level for @$days;
         my @synopses = map { @{ $_->synopses } } @$days;
 
-        # in the future we will allow more of these values to be toggled
         my $columns = {
             time => single_interval($merge_level) && !$hidden->{time},
             date => !$hidden->{date},
@@ -186,6 +187,7 @@ sub display {
             description => !$hidden->{description},
             duration    => !$hidden->{duration},
         };
+        $show_year &&= $columns->{date};
         my $format = _define_format( \@synopses, $columns, $screen_width );
 
         # keep track of various durations
@@ -198,11 +200,9 @@ sub display {
         };
 
         # display synopses and add up durations
-        my $previous;
         for my $d (@$days) {
             $d->times($times);
-            $d->display( $previous, $format, $columns, $screen_width );
-            $previous = $d;
+            $d->display( $format, $columns, $screen_width, $show_year );
         }
 
         unless ( $hidden->{totals} ) {
@@ -283,20 +283,21 @@ sub _define_format {
         $hash->{formats}{duration} = sprintf '%%%ds', $hash->{widths}{duration};
     }
     if ( $hash->{description} ) {
-        if ($screen_width == -1) {
+        if ( $screen_width == -1 ) {
             $hash->{formats}{description} = '%s';
-        } else {
-        $margins++;
-        my $max_description = $screen_width;
-        for my $col (qw(time duration tags)) {
-            $max_description -= $hash->{widths}{$col} || 0;
         }
-        $max_description -= $margins * 2;    # left margins
-        $max_description -= MARGIN;          # margin on the right
-        $max_description = MIN_WIDTH if $max_description < MIN_WIDTH;
-        $hash->{widths}{description} = $max_description;
-        $hash->{formats}{description} = sprintf '%%-%ds', $max_description;
-    }
+        else {
+            $margins++;
+            my $max_description = $screen_width;
+            for my $col (qw(time duration tags)) {
+                $max_description -= $hash->{widths}{$col} || 0;
+            }
+            $max_description -= $margins * 2;    # left margins
+            $max_description -= MARGIN;          # margin on the right
+            $max_description = MIN_WIDTH if $max_description < MIN_WIDTH;
+            $hash->{widths}{description} = $max_description;
+            $hash->{formats}{description} = sprintf '%%-%ds', $max_description;
+        }
     }
 
     my $format = '';
@@ -337,7 +338,7 @@ App::JobLog::Log::Format - pretty printer for log
 
 =head1 VERSION
 
-version 1.007
+version 1.008
 
 =head1 DESCRIPTION
 
@@ -349,7 +350,8 @@ This module handles word wrapping, date formatting, and the like.
 
 Obtains a properly filtered list of L<App::JobLog::Log::Day> objects for
 a given time expression, code reference to event filtering closure, and
-hash specifying fields to hide in report. Returns reference to list of days.
+hash specifying fields to hide in report. Returns reference to list of days
+and whether the year should be shown in dates.
 
 If C<undef> is passed in as the code reference a dummy closure is constructed
 that returns the argument passed in unmodified.
@@ -357,8 +359,9 @@ that returns the argument passed in unmodified.
 =head2 display
 
 Augments L<App::JobLog::Log::Day> objects with appropriate L<App::JobLog::Log::Synopsis> objects
-given the merge level and hidden fields. Expects a reference to a list of days, the merge level,
-and a reference to the hidden columns hash. Prints synopses to STDOUT along with aggregate
+given the merge level and hidden fields. Expects a reference to a list of days, the merge level, 
+a reference to the hidden columns hash, the width of the screen in columns, and whether the year
+should be displayed when showing dates. Prints synopses to STDOUT along with aggregate
 statistics for the interval.
 
 =head2 wrap
